/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Used to customize the rendering of the file info section in the list. All other elements of the default template, such as file icon, action buttons, upload progress etc. will be preserved in place. ([See example.](slug:templates_upload#toc-file-info-template))
 *
 * The following context variables are available in the template:
 *
 * * `let-files`&mdash;Provides a reference to the files which are associated with the current item.
 * * `let-state`&mdash;Gets a reference to the current state of each file. If the [`batch`](slug:api_upload_uploadcomponent#toc-batch) option of the Upload is set to `true`, the field reflects the state of the whole batch.
 * * `#myUpload="kendoUpload"` or `#myFileSelect="kendoFileSelect"`&mdash;Provides a reference to the instance of the Upload/FileSelect component. It is exported as `kendoUpload`/`kendoFileSelect` by using the [`exportAs`](https://angular.io/api/core/Component) metadata property.
 *
 * @example
 * ```html
 * <kendo-upload #myUpload="kendoUpload" ... >
 *     <ng-template kendoUploadFileInfoTemplate let-files let-state>
 *         <div>Name: {{ files[0].name }}</div>
 *         ...
 *     </ng-template>
 * </kendo-upload>
 * ```
 */
export declare class FileInfoTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<FileInfoTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FileInfoTemplateDirective, "[kendoUploadFileInfoTemplate], [kendoFileSelectFileInfoTemplate]", never, {}, {}, never, never, true, never>;
}
